@@ -15,21 +15,19 @@ test_that("r2cff generally works", {
   expect_output(r2cff(descFile), "cff-version")
   expect_output(r2cff(jsonliteFile), "cff-version")
   expect_output(r2cff(covrFile), "cff-version")
+  expect_output(r2cff("covr"), "cff-version")
   expect_error(r2cff(utilsFile))
   expect_error(r2cff(yamlFile))
 })
 
 test_that("Exporting works", {
-  expect_invisible(r2cff(descFile, export = TRUE))
-  expect_message(r2cff(descFile, export = TRUE), "CITATION.cff already exists")
-  filesToRemove <- list.files(pattern = "CITATION")
-  file.remove(filesToRemove)
+  withr::with_tempdir({
+    file.copy(descFile, ".")
+    expect_message(r2cff(".", export = TRUE), "Added CITATION.cff file")
+    expect_message(r2cff(".", export = TRUE), "Updated CITATION.cff file")
+  })
 })
 
 test_that("Exceptions are properly handled", {
-  expect_error(r2cff("inexistent_file"), "file not found")
-  tempFile <- tempfile()
-  writeLines(readLines(descFile)[-2], tempFile)
-  expect_warning(r2cff(tempFile, export = TRUE), "title not found.")
-  file.remove(tempFile, "CITATION.cff")
+  expect_error(r2cff("inexistent_file"), "Cannot find DESCRIPTION")
 })
